@@ -11,9 +11,9 @@ __author__ = "Shyue Ping Ong, Michael Kocher"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "2.0"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __status__ = "Production"
-__date__ = "Jun 19 2012"
+__date__ = "Mar 2 2013"
 
 import json
 import itertools
@@ -30,9 +30,21 @@ from pymatgen.entries.computed_entries import ComputedEntry,\
 class QueryEngine(object):
     """
     This class defines a QueryEngine interface to a Mongo Collection based on
-    a set of aliases. This query engine wraps around the pymongo methods to
-    provide convenient translation between various pymatgen objects and
-    database objects.
+    a set of aliases. This query engine also provides convenient translation
+    between various pymatgen objects and database objects.
+
+    The major difference between the QueryEngine's query() method and pymongo's
+    find() method is the treatment of nested fields. QueryEngine's query
+    will map the final result to a root level string, while pymmongo will
+    return the doc as is. For example, let's say you have a document
+    that is of the following form::
+
+        {"a": {"b" : 1}}
+
+    Using pymongo.find({}, fields=["a.b"]), you will get a doc where you need
+    to do doc["a"]["b"] to access the final result (1). Using
+    QueryEngine.query(properties=["a.b"], you will obtain a result that can be
+    accessed simply as doc["a.b"].
     """
 
     def __init__(self, host="127.0.0.1", port=27017, database="vasp",
@@ -86,9 +98,10 @@ class QueryEngine(object):
         """
         self.host = host
         self.port = port
-        self.database = database
+        self.database_name = database
+        self.collection_name = collection
         self.connection = MongoClient(self.host, self.port)
-        self.db = self.connection[self.database]
+        self.db = self.connection[database]
         if user:
             self.db.authenticate(user, password)
         self.collection = self.db[collection]
@@ -302,6 +315,28 @@ class QueryEngine(object):
             cur.limit(limit)
             return QueryResults(prop_dict, cur)
 
+    def query_one(self, properties=None, criteria=None, index=0):
+        """
+        Just like query, but return a single doc.
+
+        Args:
+            properties:
+                Properties to query for. Defaults to None which means all
+                supported properties.
+            criteria:
+                Criteria to query for as a dict.
+            index:
+                Similar definition to pymongo.collection.find method.
+
+        Returns:
+            A single dict containing the result.
+        """
+
+        for r in self.query(properties=properties, criteria=criteria,
+                            index=index, limit=1):
+            return r
+        return None
+
     def get_structure_from_id(self, task_id, final_structure=True):
         """
         Returns a structure from the database given the task id.
@@ -326,7 +361,28 @@ class QueryEngine(object):
 
     def __repr__(self):
         return "QueryEngine: {}:{}/{}".format(self.host, self.port,
-                                              self.database)
+                                              self.database_name)
+
+    @staticmethod
+    def from_config(config_file):
+        """
+        Initialize a QueryEngine from a JSON config file generated using mgdb
+        init.
+
+        Args:
+            config_file:
+                Filename of config file.
+
+        Returns:
+            QueryEngine
+        """
+        with open(config_file) as f:
+            d = json.load(f)
+            return QueryEngine(
+                host=d["host"], port=d["port"], database=d["database"],
+                user=d["readonly_user"], password=d["readonly_password"],
+                collection=d["collection"],
+                aliases_config=d.get("aliases_config", None))
 
 
 class QueryResults(Iterable):
