@@ -1,5 +1,5 @@
 """
-WSGI config for testsite project.
+WSGI config for webui project.
 
 This module contains the WSGI application used by Django's development server
 and any production WSGI deployments. It should expose a module-level variable
@@ -15,7 +15,7 @@ framework.
 """
 import os
 
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "testsite.settings")
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "matgendb.webui.settings")
 
 # This application object is used by any WSGI server configured to use this
 # file. This includes Django's development server, if the WSGI_APPLICATION
